@@ -17,11 +17,11 @@ App::VOJournal::VOTL - deal with vimoutliner files
 
 =head1 VERSION
 
-Version 0.4.0
+Version 0.4.1
 
 =cut
 
-use version; our $VERSION = qv('0.4.0');
+use version; our $VERSION = qv('0.4.1');
 
 =head1 SYNOPSIS
 
@@ -225,24 +225,9 @@ sub read_file {
     if (open my $input, '<', $filename) {
         $self->{objects} = [];
         while (<$input>) {
-            if (/^(\t*)([:;|<>])(.*)$/) {
+            if (/^(\t*)(.*)$/) {
                 $self->_add_something($1, {
                     children => [],
-                    type => $2,
-                    value => $3
-                }, $filter);
-            }
-            elsif (/^(\t*)(\[[_X]\])(.*)$/) {
-                $self->_add_something($1, {
-                    children => [],
-                    type => $2,
-                    value => $3
-                }, $filter);
-            }
-            elsif (/^(\t*)([^\t].*)$/) {
-                $self->_add_something($1, {
-                    children => [],
-                    type => '',
                     value => $2
                 }, $filter);
             }
@@ -401,7 +386,7 @@ sub _add_something {
 sub _checked_box {
     my ($object) = @_;
 
-    return ($object->{type} =~ /^\[X\]$/);
+    return ($object->{value} =~ /^\[X\]/);
 } # _checked_box()
 
 sub _descend_objects {
@@ -427,7 +412,7 @@ sub _descend_objects {
 sub _unchecked_box {
     my ($object) = @_;
 
-    return ($object->{type} =~ /^\[_\]$/);
+    return ($object->{value} =~ /^\[_\]/);
 } # _unchecked_box()
 
 sub _write_object {
@@ -436,7 +421,7 @@ sub _write_object {
     if (defined $filter) {
         return unless ($filter->($object,$indent));
     }
-    print $outfh "\t" x $indent, $object->{type}, $object->{value}, "\n";
+    print $outfh "\t" x $indent, $object->{value}, "\n";
 
     foreach my $co (@{$object->{children}}) {
         _write_object($co,$indent + 1,$outfh,$filter);
